@@ -10,8 +10,8 @@ keycloak_env = {
 
 luca_env = {
     'server_url': 'https://dev.luca-bds.com/luca-api',
-    'username': 'luca',
-    'password': '1234'
+    'username': 'user',
+    'password': 'pass'
 }
 
 @pytest.fixture
